@@ -2,7 +2,7 @@ class GuiActions:
     tab = "↔TAB"
     leave   = "Sair"
     edit = "Editar"
-    move = "Mover"
+    filter = "Filtrar"
     principal = "Principal"
     github = "Web   "
     help = "Ajuda"
@@ -21,17 +21,10 @@ class GuiActions:
     all = "Todos"
 
 class GuiKeys:
-    left = "A"
-    right = "D"
-    down = "S"
-    up = "W"
-
-    left2 = "H"
-    right2 = "L"
-    down2 = "J"
-    up2 = "K"
     calibrate = "C"
 
+    xray = "X"
+
     palette = "c"
     images = "I"
     down_task = "b"
@@ -39,15 +32,19 @@ class GuiKeys:
     key_help = "?"
     
     # rate = "R"
-    set_lang_drafts = "R"
+    set_lang_drafts = "L"
     open_url = "u"
     key_quit = "q"
     edit= "e"
     colors = "C"
     borders = "B"
+    graph = "1"
+    tracks = "2"
+    show_quests = "3"
+    show_tasks = "4"
     search = "/"
-    graph = "\t"
     grade_play = "p"
+    grade_play2 = "."
     execute_tester = "r" # Interact in manual input
     diff = "d"
     evaluate = "\n"
@@ -56,5 +53,4 @@ class GuiKeys:
     lock = "u"
     limite  = "t"
     expand = ">"
-    collapse = "<"
-    hidden = "E"
\ No newline at end of file
+    collapse = "<"
\ No newline at end of file
