@@ -24,25 +24,27 @@ class Executable:
             cmd = []
         if files is None:
             files = []
-        self.__cmd = cmd
-        self.__files = files
-        self.__folder = folder
+        self.__cmd_list: list[str] = cmd
+        self.__folder: str | None = folder
         self.__compiled: bool = False
-        self.__compile_error = False
+        self.__compile_error: bool = False
         self.__error_msg: Text = Text()
+        self.need_shell_mode: bool = False # subprocess needs bash mode to process symbols like & or |
     
     def set_executable(self, cmd: list[str], files: list[str], folder: str | None = None):
         self.__compiled = True
-        self.__cmd = cmd
-        if folder is not None and " " in folder:
-            folder = '"' + folder + '"'
-        self.__files = fix_spaces(files)
+        self.__cmd_list = cmd
+        self.__files = files
         self.__folder = folder
         return self
     
-    def get_command(self) -> tuple[str, str | None]:
-        cmd = " ".join(self.__cmd) + " " + " ".join(self.__files)
-        return cmd, None if self.__folder is None else self.__folder
+    def get_command(self) -> tuple[list[str], str | None]:
+        cmd: list[str] | str = self.__cmd_list
+        if isinstance(cmd, str):
+            cmd += " " + " ".join(self.__files)
+        else:
+            cmd += self.__files
+        return cmd, self.__folder
 
     def set_compile_error(self, error_msg: Text | str):
         self.__compiled = True
@@ -62,15 +64,6 @@ class Executable:
     def get_error_msg(self):
         return self.__error_msg
 
-def fix_spaces(file_list: list[str]) -> list[str]:
-    fixed_list: list[str] = []
-    for path in file_list:
-        if " " in path and not path.startswith('"'):
-            fixed_list.append(f'"{path}"')
-        else:
-            fixed_list.append(path)
-    return fixed_list
-
 class SolverBuilder:
     def __init__(self, args_list: list[str]):
         self.args_list: list[str] = [os.path.normpath(SolverBuilder.__add_dot_bar(path)) for path in args_list]
@@ -129,7 +122,7 @@ class SolverBuilder:
         first = self.args_list[0]
 
         if first.endswith(".py"):
-            self.__exec.set_executable(["python3"], self.args_list, "")
+            self.__prepare_python()
         elif first.endswith(".yaml"):
             self.__prepare_yaml()
         elif first.endswith(".mk"):
@@ -151,18 +144,24 @@ class SolverBuilder:
         else:
             self.__exec.set_executable(self.args_list, [], "")
 
+    def __prepare_python(self):
+        cmd_name = "python3"
+        if shutil.which(cmd_name) is None:
+            cmd_name = "python"
+        self.__exec.set_executable([cmd_name], self.args_list, "")
+
     def __prepare_java(self):
         self.check_tool("javac")
 
         first = self.args_list[0]
 
         filename = os.path.basename(first)
-        cmd = ["javac"] + fix_spaces(self.args_list) + ['-d', self.cache_dir]
-        return_code, stdout, stderr = Runner.subprocess_run(" ".join(cmd))
+        cmd: list[str] = ["javac"] + self.args_list + ['-d', self.cache_dir]
+        return_code, stdout, stderr = Runner.subprocess_run(cmd)
         if return_code != 0:
             self.__exec.set_compile_error(stdout + stderr)
         else:
-            self.__exec.set_executable(["java", "-cp "], [self.cache_dir, filename[:-5]])  # removing the .java
+            self.__exec.set_executable(["java", "-cp"], [self.cache_dir, filename[:-5]])  # removing the .java
 
     def update_input_function(self, free_run_mode: bool, path_list: list[str], copy_dir: str):
         new_files: list[str] = []
@@ -220,6 +219,7 @@ class SolverBuilder:
         folder = os.path.dirname(solver)
         content = Decoder.load(solver)
         yaml_data = yaml.safe_load(content)
+        self.__exec.need_shell_mode = True
 
         if "build" in yaml_data and yaml_data["build"] is not None:
             build_txt = yaml_data["build"]
@@ -234,14 +234,14 @@ class SolverBuilder:
             raise Warning(Text.format("{r}: Seu arquivo yaml precisa ter um campo {g} ", "Falha", "run:"))
         if not isinstance(yaml_data["run"], str):
             raise Warning(Text.format("{r}: O campo run deve ser uma lista", "Falha"))
-        self.__exec.set_executable([yaml_data["run"]], [], folder)
+        self.__exec.set_executable(yaml_data["run"], [], folder)
 
     def __prepare_make(self):
         self.check_tool("make")
         solver = os.path.abspath(self.args_list[0])
         folder = os.path.dirname(solver)
         cmd = ["make", "-s", "-C", folder, "-f", solver, "build"]
-        return_code, stdout, stderr = Runner.subprocess_run(" ".join(cmd))
+        return_code, stdout, stderr = Runner.subprocess_run(cmd)
         if return_code != 0:
             self.__exec.set_compile_error(stdout + stderr)
         else:
@@ -267,14 +267,14 @@ class SolverBuilder:
         if os.name == "nt":
             transpiler += ".cmd"
 
-        new_files = [os.path.abspath(x) for x in new_files]
+        new_files = [os.path.abspath(x) for x in new_files]        
         self.cache_dir = os.path.abspath(self.cache_dir)
 
         self.check_tool(transpiler)
         self.check_tool("node")
-        transpiler = "npx esbuild"
-        cmd = [transpiler] + new_files + ["--outdir=" + self.cache_dir, "--format=cjs", "--log-level=error"]
-        return_code, stdout, stderr = Runner.subprocess_run(" ".join(cmd))
+        transpiler = ["npx", "esbuild"]
+        cmd: list[str] = transpiler + new_files + ["--outdir=" + self.cache_dir, "--format=cjs", "--log-level=error"]
+        return_code, stdout, stderr = Runner.subprocess_run(cmd)
 
         if return_code != 0:
             self.__exec.set_compile_error(stdout + stderr)
@@ -282,15 +282,14 @@ class SolverBuilder:
             new_source_list: list[str] = []
             for source in new_files:
                 new_source_list.append(os.path.join(self.cache_dir, os.path.basename(source)[:-2] + "js"))
-            self.__exec.set_executable(["node"], new_source_list)  # renaming solver to main
+            self.__exec.set_executable(cmd=["node"], files=new_source_list)  # renaming solver to main
 
     def __prepare_c_cpp(self, pre_args: list[str], pos_args: list[str]):
-        # solver = self.path_list[0]
         tempdir = self.cache_dir
         source_list = [x for x in self.args_list if not x.endswith(".h") and not x.endswith(".hpp")]
         exec_path = os.path.join(tempdir, ".a.out")
         cmd = pre_args + source_list + ["-o", exec_path] + pos_args
-        return_code, stdout, stderr = Runner.subprocess_run(" ".join(cmd))
+        return_code, stdout, stderr = Runner.subprocess_run(cmd)
         if return_code != 0:
             self.__exec.set_compile_error(stdout + stderr)
         else:
